Name: missing-epoch-in-dependency/binary
Files:
 aade379480f4f5e93dd8562462cf686a385d8a46  python-pyentropy_0.4.1-1_all.deb
Test-For:
 w: python-pyentropy: missing-epoch-in-dependency python-numpy (>= 1.3)

Name: missing-epoch-in-dependency/source
Files:
 5faf3b6185937f04ad566b871b7398b75c43ccc9  nipy_0.1.999-2.dsc
 a0f2ac914064be16fd1da60441023d88376621c8  nipy_0.1.999.orig.tar.gz
 e461e9144cc82f032487dc46a146db252c71e113  nipy_0.1.999-2.debian.tar.gz
Test-For:
 w: nipy source: missing-epoch-in-dependency python-numpy (>= 1.2)

Name: hardcoded-dependency-on-numpy-virtual-package
Files:
 467ebde343a63dc7e23e87c154092b6512c0268d  mathgl_1.11.2-14.dsc
 3e947b029b28eac45c0b241438f54c751902b434  mathgl_1.11.2-14.debian.tar.gz
 16b9ab58e654c5b91374f8a35eafc33630d7f5c0  mathgl_1.11.2.orig.tar.gz
Test-For:
 e: mathgl source: hardcoded-dependency-on-numpy-virtual-package python-numpy-abi9

Name: obsolete-field
Files:
 57e235913a75a8f88a71cb5ced79f4b38e032c56  python-clientcookie_1.3.0-1.2_all.deb
Test-For:
 i: python-clientcookie: obsolete-conflicts python2.3-clientcookie
 i: python-clientcookie: obsolete-conflicts python2.4-clientcookie
 i: python-clientcookie: obsolete-replaces python2.3-clientcookie
 i: python-clientcookie: obsolete-replaces python2.4-clientcookie
 i: python-clientcookie: obsolete-provides python2.4-clientcookie
