Name: misssing-dependency-for-sys.path-addition
Files:
 3e2a2a328edfc1058abc2f5da9650ad189895f46  python-osmgpsmap_0.7.3-2_i386.deb
Test-For:
 e: python-osmgpsmap: misssing-dependency-for-sys.path-addition gtk-2.0 => python-gobject-2 | python-gtk2
Info: http://bugs.debian.org/680815

Name: pth-file-modifies-sys.path
Files:
 1eb4373c77b123998fb5216fa05a942f72a88a46  python-input-pad_1.0.1-2_i386.deb
Test-For:
 e: python-input-pad: pth-file-modifies-sys.path usr/share/pyshared/pyinput_pad.pth input-pad-1.0
