Name: http-pypi-url
Files:
 20bec191acde70fdb5f445f2e6a09058241fecf4  flufl.enum_3.3.2-1.dsc
 b2943b038f585e31437baff8ab9af80fd44224a1  flufl.enum_3.3.2-1.debian.tar.gz
 6c60f4bafd56b263d9a3cd577aca3e7abe78abe3  flufl.enum_3.3.2.orig.tar.gz
Test-For:
 i: flufl.enum source: http-pypi-url

Name: https-pypi-url
Files:
 822b200383bd26e701f84557c4de72f8ee16e332  pycparser_2.09.1+dfsg-2.debian.tar.gz
 0a21ef6e57e30645ee7f7269d55422d57f3d602e  pycparser_2.09.1+dfsg-2.dsc
 bc09fd5c7771b39d134ff44cd08b9a14afcaf6d5  pycparser_2.09.1+dfsg.orig.tar.gz
Test-Against:
 i: pycparser source: http-pypi-url
