Name: incorrect-package-name/pth
Files:
 1eb4373c77b123998fb5216fa05a942f72a88a46  python-input-pad_1.0.1-2_i386.deb
Test-Against:
 x: python-input-pad: incorrect-package-name python-input-pad-1.0
Info:
 Fixed in lintian4python 0.8.  Prior versions did not take .pth contents into
 account.

Name: incorrect-package-name/python2-extension
Files:
 00ec7687ba7ffe7ae87db27392d0f266b6428df9  python-pylibacl_0.5.1-1.1_i386.deb
Test-For:
 x: python-pylibacl: incorrect-package-name python-posix1e

Name: incorrect-package-name/python3-extension
Files:
 b2f23883d7e50d8b09bc5d6d875a7ed4fcd10ff5  python3-pylibacl_0.5.1-1.1_i386.deb
Test-For:
 x: python3-pylibacl: incorrect-package-name python3-posix1e
Info:
 Fixed in lintian4python 0.13.1.  Prior versions did not take Python 3
 extensions into account.
