Name: incorrect-team-name/papt
Files:
 c1fc458ec2f1d76238837f2ddbf7771848b5c32c  s3ql_1.12-1_i386.deb
Test-For:
 w: s3ql: incorrect-team-name Debian Python Apps Team -> Python Applications Packaging Team

Name: incorrect-vcs-field
Files:
 fa6649b85208100c9be42dbd57be111fc7132180  bjsonrpc_0.2.0-1.dsc
 20af63f9706a9188e23ddcad45d93936a27e6aab  bjsonrpc_0.2.0-1.debian.tar.bz2
 446ed948bf95a79087a49d354caa71bf0436ca04  bjsonrpc_0.2.0.orig.tar.gz
Test-For:
 w: bjsonrpc source: incorrect-vcs-field vcs-svn svn://svn.debian.org/svn/python-apps/packages/bjsonrpc/trunk -> svn://anonscm.debian.org/python-modules/packages/bjsonrpc/trunk/
 w: bjsonrpc source: incorrect-vcs-field vcs-browser http://svn.debian.org/viewsvn/python-apps/packages/bjsonrpc/trunk/ -> http://anonscm.debian.org/viewvc/python-modules/packages/bjsonrpc/trunk/

Name: missing-vcs-field/dpmt
Files:
 2c728ed51f42c23059cca6136333468c1f7a378a  cssutils_0.9.7~b2-2.dsc
 4661a5780097bbb1d3c269d757f04de5f3884d62  cssutils_0.9.7~b2-2.diff.gz
 d3536e60df9133912890626e3b3e991bfc603430  cssutils_0.9.7~b2.orig.tar.gz
Test-For:
 w: cssutils source: missing-vcs-field vcs-svn svn://anonscm.debian.org/python-modules/packages/cssutils/trunk/
 w: cssutils source: missing-vcs-field vcs-browser http://anonscm.debian.org/viewvc/python-modules/packages/cssutils/trunk/

Name: missing-vcs-field/papt
Files:
 a2ce92a0e300a108738271b4ae97766f3d61fa3c  mimms_3.2.1-2.dsc
 ecfb1659a1256793e9c7af6192e50042cfb6c7e3  mimms_3.2.1-2.diff.gz
 2f7a6b526740276a545eae8f6b5424bb2a229c44  mimms_3.2.1.orig.tar.gz
Test-For:
 w: mimms source: missing-vcs-field vcs-svn svn://anonscm.debian.org/python-apps/packages/mimms/trunk/
 w: mimms source: missing-vcs-field vcs-browser http://anonscm.debian.org/viewvc/python-apps/packages/mimms/trunk/
