# python::watch -- lintian check script -*- perl -*-
#
# Copyright © 2013 Jakub Wilk
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::python::watch;

use strict;
use warnings;

use Lintian::Tags qw(tag);

sub run {

    my (undef, undef, $info) = @_;
    my $wfile = $info->debfiles('watch');
    return if -l $wfile;
    return if ! -f $wfile;
    open (my $fh, '<', $wfile) or fail("cannot open watch file: $!");
    while (<$fh>) {
        if (m,\b\Qhttp://pypi.python.org/\E,) {
            tag 'http-pypi-url';
            last;
        }
    }
    close($fh);
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
