Name: python-module-in-multi-arch-foreign-package/extension
Files:
 64bdfaac06a19495439e1aca41b7ff8c31477079  python-rivet_1.8.0-1_i386.deb
Test-For:
 e: python-rivet: python-module-in-multi-arch-foreign-package

Name: python-module-in-multi-arch-foreign-package/pure-python
Files:
 2bfb202a9e17e12aa4bb6dacf80612e33ef4d453  python-dput_1.0_all.deb
Test-For:
 e: python-dput: python-module-in-multi-arch-foreign-package

Name: insufficient-any-dependency
Files:
 1f92115d9fafdaf1089fec2e5486346eee6e2c1f  imposm_2.5.0-3_all.deb
Test-For:
 e: imposm: insufficient-any-dependency python:any => python:any (>= 2.7.5-5~)
